summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAlexander Golin <agolin95@gmail.com>2022-01-14 14:41:24 -0500
committerAlexander Golin <agolin95@gmail.com>2022-01-14 14:41:24 -0500
commit746330c67f5d3e63f60597b754da3388a3c4a6c9 (patch)
treef275abbae0012c33d3f26a7caf69a5bee2b9db71
parentc72a57da38709163d8f79792519c4939c540c383 (diff)
downloadmongo-SERVER-62595.tar.gz
update log.h references to logv2/README.mdSERVER-62595
-rw-r--r--src/mongo/logv2/log.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/logv2/log.h b/src/mongo/logv2/log.h
index 7cfe6aa4ec3..27e8f9f52fe 100644
--- a/src/mongo/logv2/log.h
+++ b/src/mongo/logv2/log.h
@@ -65,11 +65,11 @@ const mongo::logv2::LogComponent MongoLogV2DefaultComponent_component =
#else
#error \
"mongo/logv2/log.h requires MONGO_LOGV2_DEFAULT_COMPONENT to be defined. " \
- "Please see https://github.com/mongodb/mongo/blob/master/src/mongo/logv2/README.md "
+ "Please see https://github.com/mongodb/mongo/blob/master/docs/logging.md "
#endif // MONGO_LOGV2_DEFAULT_COMPONENT
} // namespace
// The logging macros below are documented in detail under src/mongo/logv2/README.md
namespace mongo {
// Internal helper to be able to create LogOptions with two arguments from other macros
#define MAKE_OPTIONS_ARG2(ARG0, ARG1) \
@@ -65,11 +65,11 @@ const mongo::logv2::LogComponent MongoLogV2DefaultComponent_component =
#endif // MONGO_LOGV2_DEFAULT_COMPONENT
} // namespace
-// The logging macros below are documented in detail under src/mongo/logv2/README.md
+// The logging macros below are documented in detail under docs/logging.md
namespace mongo {
// Internal helper to be able to create LogOptions with two arguments from other macros